alliance

package module
v1.3.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 12, 2022 License: MIT Imports: 10 Imported by: 1

README

alliance

CommonJS and AMD modules compile library written in Golang.

How To Use:

import (
	"io/ioutil"
	"github.com/night-codes/alliance"
)

gzip := false
if str, err := alliance.Make("files/js/", alliance.Options{...}); err == nil {
	err = ioutil.WriteFile("build.js", []byte(str), 0644)
}

Projects:

CommonJS modules compiler written on golang: https://github.com/night-codes/jss

License

MIT License

Copyright (c) 2018 Oleksiy Chechel (alex.mirrr@gmail.com)

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Make

func Make(path string, options ...Options) (string, error)

Make one script from modules directory

Types

type Options added in v1.2.0

type Options struct {
	Only   []string
	Ignore []string
	Gzip   bool
	Minify bool
}

Jump to